package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallUploadFileMapper;
import com.ruoyi.mall.domain.MallUploadFile;
import com.ruoyi.mall.service.IMallUploadFileService;

/**
 * 资源文件Service业务层处理
 * 
 * @author chang
 * @date 2021-11-25
 */
@Service
public class MallUploadFileServiceImpl implements IMallUploadFileService 
{
    @Autowired
    private MallUploadFileMapper mallUploadFileMapper;

    /**
     * 查询资源文件
     * 
     * @param id 资源文件主键
     * @return 资源文件
     */
    @Override
    public MallUploadFile selectMallUploadFileById(String id)
    {
        return mallUploadFileMapper.selectMallUploadFileById(id);
    }

    /**
     * 查询资源文件列表
     * 
     * @param mallUploadFile 资源文件
     * @return 资源文件
     */
    @Override
    public List<MallUploadFile> selectMallUploadFileList(MallUploadFile mallUploadFile)
    {
        return mallUploadFileMapper.selectMallUploadFileList(mallUploadFile);
    }

    /**
     * 新增资源文件
     * 
     * @param mallUploadFile 资源文件
     * @return 结果
     */
    @Override
    public int insertMallUploadFile(MallUploadFile mallUploadFile)
    {
        return mallUploadFileMapper.insertMallUploadFile(mallUploadFile);
    }

    /**
     * 修改资源文件
     * 
     * @param mallUploadFile 资源文件
     * @return 结果
     */
    @Override
    public int updateMallUploadFile(MallUploadFile mallUploadFile)
    {
        return mallUploadFileMapper.updateMallUploadFile(mallUploadFile);
    }

    /**
     * 批量删除资源文件
     * 
     * @param ids 需要删除的资源文件主键
     * @return 结果
     */
    @Override
    public int deleteMallUploadFileByIds(String[] ids)
    {
        return mallUploadFileMapper.deleteMallUploadFileByIds(ids);
    }

    /**
     * 删除资源文件信息
     * 
     * @param id 资源文件主键
     * @return 结果
     */
    @Override
    public int deleteMallUploadFileById(String id)
    {
        return mallUploadFileMapper.deleteMallUploadFileById(id);
    }
}
