package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallUploadFile;
import com.ruoyi.mall.service.IMallUploadFileService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资源文件Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallUploadFile")
public class MallUploadFileController extends BaseController
{
    @Autowired
    private IMallUploadFileService mallUploadFileService;

    /**
     * 查询资源文件列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallUploadFile mallUploadFile)
    {
        startPage();
        List<MallUploadFile> list = mallUploadFileService.selectMallUploadFileList(mallUploadFile);
        return getDataTable(list);
    }

    /**
     * 导出资源文件列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:export')")
    @Log(title = "资源文件", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallUploadFile mallUploadFile)
    {
        List<MallUploadFile> list = mallUploadFileService.selectMallUploadFileList(mallUploadFile);
        ExcelUtil<MallUploadFile> util = new ExcelUtil<MallUploadFile>(MallUploadFile.class);
        return util.exportExcel(list, "资源文件数据");
    }

    /**
     * 获取资源文件详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(mallUploadFileService.selectMallUploadFileById(id));
    }

    /**
     * 新增资源文件
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:add')")
    @Log(title = "资源文件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallUploadFile mallUploadFile)
    {
        return toAjax(mallUploadFileService.insertMallUploadFile(mallUploadFile));
    }

    /**
     * 修改资源文件
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:edit')")
    @Log(title = "资源文件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallUploadFile mallUploadFile)
    {
        return toAjax(mallUploadFileService.updateMallUploadFile(mallUploadFile));
    }

    /**
     * 删除资源文件
     */
    @PreAuthorize("@ss.hasPermi('mall:mallUploadFile:remove')")
    @Log(title = "资源文件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(mallUploadFileService.deleteMallUploadFileByIds(ids));
    }
}
